import request from '@/utils/request'

//列表
export function studyFormPre_list(query) {
  return request({
    url: '/system/business/studyFormPre/list',
    method: 'get',
    params: query
  })
}
//稽查轨迹
export function studyFormPre_jcgj(query) {
  return request({
    url: '/system/business/studyFormPre/jcgjList',
    method: 'get',
    params: query
  })
}
//签名信息
export function studyFormPre_qmxx(query) {
  return request({
    url: '/system/business/studyFormPre/qmxxList',
    method: 'get',
    params: query
  })
}

//详情
export function studyFormPre_info(query) {
  return request({
    url: '/system/business/studyFormPre/info',
    method: 'get',
    params: query
  })
}

//保存
export function studyFormPre_bc(data) {
  return request({
    url: '/system/business/studyFormPre/bc',
    method: 'post',
    data: data
  })
}

//仅保存
export function studyFormPre_bcOnly(data) {
  return request({
    url: '/system/business/studyFormPre/bcOnly',
    method: 'post',
    data: data
  })
}
//提交
export function studyFormPre_tj(data) {
  return request({
    url: '/system/business/studyFormPre/tj',
    method: 'post',
    data: data
  })
}

//填报
export function studyFormPre_tb(data) {
  return request({
    url: '/system/business/studyFormPre/tb',
    method: 'post',
    data: data
  })
}


//通过
export function studyFormPre_tg(data) {
  return request({
    url: '/system/business/studyFormPre/tg',
    method: 'post',
    data: data
  })
}


//拒绝
export function studyFormPre_jj(data) {
  return request({
    url: '/system/business/studyFormPre/jj',
    method: 'post',
    data: data
  })
}


//保存字段勾选记录
export function studyFormPre_updateZdgxjl(data) {
  return request({
    url: '/system/business/studyFormPre/updateZdgxjl',
    method: 'post',
    data: data
  })
}

//保存复核意见
export function studyFormPre_updateFhyjjl(data) {
  return request({
    url: '/system/business/studyFormPre/updateFhyjjl',
    method: 'post',
    data: data
  })
}

//保存表单内容
export function studyFormPre_updateBdnr(data) {
  return request({
    url: '/system/business/studyFormPre/updateBdnr',
    method: 'post',
    data: data
  })
}

//申请关闭
export function studyFormPre_sqgb(data) {
  return request({
    url: '/system/business/studyFormPre/sqgb',
    method: 'post',
    data: data
  })
}

//同意关闭
export function studyFormPre_tygb(data) {
  return request({
    url: '/system/business/studyFormPre/tygb',
    method: 'post',
    data: data
  })
}

//拒绝关闭
export function studyFormPre_jjgb(data) {
  return request({
    url: '/system/business/studyFormPre/jjgb',
    method: 'post',
    data: data
  })
}

// 查询试验列表
export function studyFormPre_studyList(query) {
  return request({
    url: '/system/business/studyFormPre/studyList',
    method: 'get',
    params: query
  })
}

// 查询试验预填表单列表
export function studyFormPre_studyFormPreList(query) {
  return request({
    url: '/system/business/studyFormPre/studyFormPreList',
    method: 'get',
    params: query
  })
}